==> zio-aws-omics_2.12-5.20.22.1-sources.jar: zio/aws/omics/model/ReadSetStatus.scala <==
package zio.aws.omics.model
import scala.jdk.CollectionConverters._
sealed trait ReadSetStatus {
  def unwrap: software.amazon.awssdk.services.omics.model.ReadSetStatus
}
object ReadSetStatus {
  def wrap(
      value: software.amazon.awssdk.services.omics.model.ReadSetStatus
  ): zio.aws.omics.model.ReadSetStatus = value match {
    case software.amazon.awssdk.services.omics.model.ReadSetStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.omics.model.ReadSetStatus.ARCHIVED =>
      val r = ARCHIVED
      r
    case software.amazon.awssdk.services.omics.model.ReadSetStatus.ACTIVATING =>
      val r = ACTIVATING
      r
    case software.amazon.awssdk.services.omics.model.ReadSetStatus.ACTIVE =>
      val r = ACTIVE
      r
    case software.amazon.awssdk.services.omics.model.ReadSetStatus.DELETING =>
      val r = DELETING
      r
    case software.amazon.awssdk.services.omics.model.ReadSetStatus.DELETED =>
      val r = DELETED
      r
  }
  case object unknownToSdkVersion extends zio.aws.omics.model.ReadSetStatus {
    override def unwrap
        : software.amazon.awssdk.services.omics.model.ReadSetStatus =
      software.amazon.awssdk.services.omics.model.ReadSetStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object ARCHIVED extends zio.aws.omics.model.ReadSetStatus {
    override def unwrap
        : software.amazon.awssdk.services.omics.model.ReadSetStatus =
      software.amazon.awssdk.services.omics.model.ReadSetStatus.ARCHIVED
  }
  case object ACTIVATING extends zio.aws.omics.model.ReadSetStatus {
    override def unwrap
        : software.amazon.awssdk.services.omics.model.ReadSetStatus =
      software.amazon.awssdk.services.omics.model.ReadSetStatus.ACTIVATING
  }
  case object ACTIVE extends zio.aws.omics.model.ReadSetStatus {
    override def unwrap
        : software.amazon.awssdk.services.omics.model.ReadSetStatus =
      software.amazon.awssdk.services.omics.model.ReadSetStatus.ACTIVE
  }
  case object DELETING extends zio.aws.omics.model.ReadSetStatus {
    override def unwrap
        : software.amazon.awssdk.services.omics.model.ReadSetStatus =
      software.amazon.awssdk.services.omics.model.ReadSetStatus.DELETING
  }
  case object DELETED extends zio.aws.omics.model.ReadSetStatus {
    override def unwrap
        : software.amazon.awssdk.services.omics.model.ReadSetStatus =
      software.amazon.awssdk.services.omics.model.ReadSetStatus.DELETED
  }
}

==> zio-aws-omics_2.12-6.20.74.1-sources.jar: zio/aws/omics/model/ReadSetStatus.scala <==
package zio.aws.omics.model
import scala.jdk.CollectionConverters._
sealed trait ReadSetStatus {
  def unwrap: software.amazon.awssdk.services.omics.model.ReadSetStatus
}
object ReadSetStatus {
  def wrap(
      value: software.amazon.awssdk.services.omics.model.ReadSetStatus
  ): zio.aws.omics.model.ReadSetStatus = value match {
    case software.amazon.awssdk.services.omics.model.ReadSetStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.omics.model.ReadSetStatus.ARCHIVED =>
      val r = ARCHIVED
      r
    case software.amazon.awssdk.services.omics.model.ReadSetStatus.ACTIVATING =>
      val r = ACTIVATING
      r
    case software.amazon.awssdk.services.omics.model.ReadSetStatus.ACTIVE =>
      val r = ACTIVE
      r
    case software.amazon.awssdk.services.omics.model.ReadSetStatus.DELETING =>
      val r = DELETING
      r
    case software.amazon.awssdk.services.omics.model.ReadSetStatus.DELETED =>
      val r = DELETED
      r
    case software.amazon.awssdk.services.omics.model.ReadSetStatus.PROCESSING_UPLOAD =>
      val r = PROCESSING_UPLOAD
      r
    case software.amazon.awssdk.services.omics.model.ReadSetStatus.UPLOAD_FAILED =>
      val r = UPLOAD_FAILED
      r
  }
  case object unknownToSdkVersion extends zio.aws.omics.model.ReadSetStatus {
    override def unwrap
        : software.amazon.awssdk.services.omics.model.ReadSetStatus =
      software.amazon.awssdk.services.omics.model.ReadSetStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object ARCHIVED extends zio.aws.omics.model.ReadSetStatus {
    override def unwrap
        : software.amazon.awssdk.services.omics.model.ReadSetStatus =
      software.amazon.awssdk.services.omics.model.ReadSetStatus.ARCHIVED
  }
  case object ACTIVATING extends zio.aws.omics.model.ReadSetStatus {
    override def unwrap
        : software.amazon.awssdk.services.omics.model.ReadSetStatus =
      software.amazon.awssdk.services.omics.model.ReadSetStatus.ACTIVATING
  }
  case object ACTIVE extends zio.aws.omics.model.ReadSetStatus {
    override def unwrap
        : software.amazon.awssdk.services.omics.model.ReadSetStatus =
      software.amazon.awssdk.services.omics.model.ReadSetStatus.ACTIVE
  }
  case object DELETING extends zio.aws.omics.model.ReadSetStatus {
    override def unwrap
        : software.amazon.awssdk.services.omics.model.ReadSetStatus =
      software.amazon.awssdk.services.omics.model.ReadSetStatus.DELETING
  }
  case object DELETED extends zio.aws.omics.model.ReadSetStatus {
    override def unwrap
        : software.amazon.awssdk.services.omics.model.ReadSetStatus =
      software.amazon.awssdk.services.omics.model.ReadSetStatus.DELETED
  }
  case object PROCESSING_UPLOAD extends zio.aws.omics.model.ReadSetStatus {
    override def unwrap
        : software.amazon.awssdk.services.omics.model.ReadSetStatus =
      software.amazon.awssdk.services.omics.model.ReadSetStatus.PROCESSING_UPLOAD
  }
  case object UPLOAD_FAILED extends zio.aws.omics.model.ReadSetStatus {
    override def unwrap
        : software.amazon.awssdk.services.omics.model.ReadSetStatus =
      software.amazon.awssdk.services.omics.model.ReadSetStatus.UPLOAD_FAILED
  }
}
